<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>AboutWindow</name>
    <message>
        <location filename="../../src/ui/about.ui" line="19"/>
        <source>About QAntenna</source>
        <translation>Om QAntenna
</translation>
    </message>
    <message>
        <location filename="../../src/ui/about.ui" line="90"/>
        <source>&lt;version&gt;</source>
        <translation>&lt;version&gt;</translation>
    </message>
    <message>
        <location filename="../../src/ui/about.ui" line="103"/>
        <source>&amp;About</source>
        <translation>&amp;Om</translation>
    </message>
    <message>
        <location filename="../../src/ui/about.ui" line="115"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;QAntenna&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;A multiplatform antenna and radiation pattern analyzer&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;http://qantenna.sf.net/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;http://qantenna.sf.net/&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;(new line)
p, li { white-space: pre-wrap; }(new line)
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;(new line)
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;QAntenna&lt;/p&gt;(new line)
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;(new line)
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;En multiplatform antenne og strålings mønster analyse&lt;/p&gt;(new line)
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;(new line)
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;http://qantenna.sf.net/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;http://qantenna.sf.net/&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../src/ui/about.ui" line="145"/>
        <source>A&amp;uthors</source>
        <translation>&amp;Udviklere</translation>
    </message>
    <message utf8="true">
        <location filename="../../src/ui/about.ui" line="157"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Lisandro Damián Nicanor Pérez Meyer&lt;br /&gt;&lt;a href=&quot;perezmeyer@gmail.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;perezmeyer@gmail.com&lt;/span&gt;&lt;/a&gt;&lt;br /&gt;&lt;br /&gt;Gustavo Gonzalez&lt;br /&gt;&lt;a href=&quot;gonzalgustavo@gmail.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;gonzalgustavo@gmail.com&lt;/span&gt;&lt;/a&gt;&lt;br /&gt;&lt;br /&gt;Pablo Odorico&lt;br /&gt;&lt;a href=&quot;gonzalgustavo@gmail.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;pablo.odorico@gmail.com&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;(new line)
p, li { white-space: pre-wrap; }(new line)
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;(new line)
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Lisandro Damián Nicanor Pérez Meyer&lt;br /&gt;&lt;a href=&quot;perezmeyer@gmail.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;perezmeyer@gmail.com&lt;/span&gt;&lt;/a&gt;&lt;br /&gt;&lt;br /&gt;Gustavo Gonzalez&lt;br /&gt;&lt;a href=&quot;gonzalgustavo@gmail.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;gonzalgustavo@gmail.com&lt;/span&gt;&lt;/a&gt;&lt;br /&gt;&lt;br /&gt;Pablo Odorico&lt;br /&gt;&lt;a href=&quot;gonzalgustavo@gmail.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;pablo.odorico@gmail.com&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../src/ui/about.ui" line="180"/>
        <source>&amp;Thanks To</source>
        <translation>&amp;Tak til</translation>
    </message>
    <message>
        <location filename="../../src/ui/about.ui" line="242"/>
        <source>&amp;License Agreement</source>
        <translation>&amp;Licens aftale</translation>
    </message>
    <message>
        <location filename="../../src/ui/about.ui" line="254"/>
        <source>This program is distributed under the terms of the  GNU General Public License Version 2&lt;br&gt;&lt;br&gt;Available &lt;a href=&quot;http://www.gnu.org/copyleft/gpl.html&quot;&gt;online&lt;/a&gt; or in the COPYING file.</source>
        <translation>Dette program er distribueret under GNU licensen version 2, den kan hentes &lt;br&gt;&lt;br&gt;her &lt;a href=&quot;http://www.gnu.org/copyleft/gpl.html&quot;&gt;online&lt;/a&gt; eller se i &quot;COPYING&quot; filen.</translation>
    </message>
    <message>
        <location filename="../../src/ui/about.ui" line="198"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:12pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Joop Stakenborg&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;  - Correct installation of translation files in UNIX systems&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;  - Dutch Translation&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;  - Testing&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Michael Barjenbruch&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;  - INSTALL file&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;  - German translation&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Louis Belmont&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;  - French translation&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Marcin Gucia&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;  - Polish translation&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Marina Goritskaia&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;  - Russian translation&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Peter Isaksen&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt; - Danish translation&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Marc Ume&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;  - Original yagi8sq_ch1.nec example&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Everaldo&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;  - Icons&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Claudio Delrieux&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt; font-weight:600;&quot;&gt;Ricardo Coppo&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt; font-weight:600;&quot;&gt;Gustavo Ramoscelli&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt; font-weight:600;&quot;&gt;T.C.A. Molteno&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt; font-weight:600;&quot;&gt;N. Kyriazis&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;See examples/LICENSE-NEC.FILES for more information on the NEC examples&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DataManager</name>
    <message>
        <location filename="../../src/datamanager.cpp" line="86"/>
        <source>Calculating</source>
        <translation>Beregner</translation>
    </message>
    <message>
        <location filename="../../src/datamanager.cpp" line="248"/>
        <source>Closing</source>
        <translation>Lukker</translation>
    </message>
    <message>
        <location filename="../../src/datamanager.cpp" line="273"/>
        <source>NEC files (*.nec)</source>
        <translation>NEC filer (*.nec)</translation>
    </message>
    <message>
        <location filename="../../src/datamanager.cpp" line="273"/>
        <source>All files (*.*)</source>
        <translation>Alle filer (*,*)</translation>
    </message>
    <message>
        <location filename="../../src/datamanager.cpp" line="292"/>
        <source>The file &quot;</source>
        <translation>filen &quot;</translation>
    </message>
    <message>
        <location filename="../../src/datamanager.cpp" line="292"/>
        <source>&quot; is already open.</source>
        <translation>&quot; er allerede ben.</translation>
    </message>
    <message>
        <location filename="../../src/datamanager.cpp" line="313"/>
        <source>Opening</source>
        <translation>Åbner</translation>
    </message>
</context>
<context>
    <name>GLWidget</name>
    <message>
        <location filename="../../src/glwidget.cpp" line="294"/>
        <source>Exploration mode: Use W, S, A and D keys to go forward, backward or move sideways</source>
        <translation>bevægelse: brug W, S, A og D tasterne for at gå fremad, tilbage og til siden</translation>
    </message>
    <message>
        <location filename="../../src/glwidget.cpp" line="334"/>
        <source>Orbital mode: Move around the antenna by dragging it</source>
        <translation>Orbital måde: flyt rundt om antennen ved at trække i den</translation>
    </message>
    <message>
        <location filename="../../src/glwidget.cpp" line="395"/>
        <source>QAntenna - DataManager</source>
        <translation>QAntenna - DataManager</translation>
    </message>
    <message>
        <location filename="../../src/glwidget.cpp" line="396"/>
        <source>I can not create the OpenGL list for the grid</source>
        <translation>Kan ikke lave OpenGL liste til gitter</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="161"/>
        <source>Welcome to</source>
        <translation>velkommen til</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="257"/>
        <source>Calculating...</source>
        <translation>Beregner...</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="279"/>
        <source>Done</source>
        <translation>Færdig</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="286"/>
        <source>Some antennas need to be calculated</source>
        <translation>nogle af antennerne, er nød til at blive beregnet</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="325"/>
        <location filename="../../src/ui/mainwindow.cpp" line="446"/>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="325"/>
        <source>No</source>
        <translation>Nej</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="498"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="500"/>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="544"/>
        <source>([0-9]+) *x *([0-9]+)</source>
        <translation>([0-9]+) *x *([0-9]+)</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="548"/>
        <source>Render into file</source>
        <translation>Gem som fil</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="549"/>
        <source>Enter the desired resolution:</source>
        <translation>Skriv den ønskede opløsning:</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="550"/>
        <source>%1 x %2</source>
        <translation>%1 x %2</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="588"/>
        <source>%1 file (*.%2);;</source>
        <translation>%1 fil (*.%2);;</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="596"/>
        <source>Save Image As</source>
        <translation>Gem billede som</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="613"/>
        <source>Rendering to &quot;&lt;font color=&quot;#000066&quot;&gt;</source>
        <translation>Gem som &quot;&lt;font color=&quot;#000066&quot;&gt;</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="618"/>
        <source>Unable to save %1.</source>
        <translation>Kan ikke gemme %1.</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="629"/>
        <source>Rendering to clipboard... </source>
        <translation>Beregner til udklipsholder... </translation>
    </message>
</context>
<context>
    <name>MainWindowQAntenna</name>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="19"/>
        <source>QAntenna</source>
        <translation>QAntenna</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="92"/>
        <source>Open file...</source>
        <translation>Åben fil...</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="95"/>
        <source>O</source>
        <translation>O</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="116"/>
        <source>Close file...</source>
        <translation>Luk fil...</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="119"/>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="132"/>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="164"/>
        <source>A</source>
        <translation>A</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="242"/>
        <source>File</source>
        <translation>Fil</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="247"/>
        <source> Frequency</source>
        <translation> Frekvens</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="252"/>
        <source> Calculated </source>
        <translation> beregnet </translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="268"/>
        <source>[Path]</source>
        <translation>[sti]</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="273"/>
        <source>[Index]</source>
        <translation>[Index]</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="310"/>
        <source>Calculate at opening</source>
        <translation>Beregn ved åbning</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="350"/>
        <source>Log</source>
        <translation>Log</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="378"/>
        <source>History:</source>
        <translation>Historik:</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="388"/>
        <source>Clean history</source>
        <translation>nulstil historik</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="453"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;(new line)
p, li { white-space: pre-wrap; }(new line)
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;(new line)
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="473"/>
        <source>Visualization</source>
        <translation>Visualisering</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="502"/>
        <source>Pattern scale</source>
        <translation>Mønster skala</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="509"/>
        <source>Transparency</source>
        <translation>Gennemsigtighed</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="516"/>
        <source>Spheres radius</source>
        <translation>kugleradius</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="523"/>
        <source>Segment radius</source>
        <translation>Udsnit radius</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="676"/>
        <source>Minimum dB at the origin</source>
        <translation>Minimum dB fra udgangspunkt</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="757"/>
        <source>Modes</source>
        <translation>Måde</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="780"/>
        <source>Surface</source>
        <translation>Overflade</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="787"/>
        <source>Spheres</source>
        <translation>Kugle</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="794"/>
        <source>Mesh</source>
        <translation>Trådnet</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="801"/>
        <source>Volumetric</source>
        <translation>Volumetrisk</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="808"/>
        <source>Show grid</source>
        <translation>Vis Net</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="878"/>
        <source>&amp;Help</source>
        <translation>&amp;Hjælp</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="885"/>
        <source>&amp;File</source>
        <translation>&amp;Fil</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="896"/>
        <source>&amp;Tools</source>
        <translation>&amp;Værktøj</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="912"/>
        <source>&amp;Quit</source>
        <translation>&amp;Afslut</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="915"/>
        <source>Quit</source>
        <translation>Afslut</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="918"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="926"/>
        <source>&amp;About...</source>
        <translation>&amp;Om...</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="929"/>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="937"/>
        <source>&amp;Open...</source>
        <translation>&amp;Åben...</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="940"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="951"/>
        <source>&amp;Close</source>
        <translation>&amp;Luk</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="954"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="965"/>
        <source>C&amp;lose all</source>
        <translation>L&amp;uk alle</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="976"/>
        <source>C&amp;alculate patterns</source>
        <translation>&amp;Beregn mønstre</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="979"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="987"/>
        <source>About &amp;Qt...</source>
        <translation>Om &amp;Qt...</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="995"/>
        <source>&amp;Render to file...</source>
        <translation>&amp;Gem til fil...</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="998"/>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="1001"/>
        <source>Render to file</source>
        <translation>Gem til fil</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="1004"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="1012"/>
        <source>Render to &amp;clipboard...</source>
        <translation>Beregner til &amp;udklipsholder... </translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="1015"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
</context>
<context>
    <name>NECContainer</name>
    <message>
        <location filename="../../src/neccontainer.cpp" line="225"/>
        <source>Rendering &quot;&lt;font color=&quot;#000066&quot;&gt;</source>
        <translation>Beregner &quot;&lt;font color=&quot;#000066&quot;&gt;</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/main.cpp" line="66"/>
        <source>Checking if there is OpenGL support in this machine</source>
        <translation>Checker om der er OpenGL support på denne maskine</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="77"/>
        <source>Loading QAntenna</source>
        <translation>Starter QAntenna</translation>
    </message>
</context>
<context>
    <name>QWidget</name>
    <message>
        <location filename="../../src/main.cpp" line="69"/>
        <source>We don&apos;t have OpenGL support</source>
        <translation>Der er ikke OpenGL support</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="71"/>
        <source>There is no OpenGL support in your system.&lt;br&gt;Closing QAntenna</source>
        <translation>Der er ingen OpenGL support i dit system.&lt;br&gt;Afslutter QAntenna</translation>
    </message>
    <message>
        <location filename="../../src/necinput.cpp" line="137"/>
        <source>While trying to insert a FR card, I could not find a GE card in order to put the first card in a right place</source>
        <translation>Under forsøg på at indsætte FR kort, kunne der ikke findes et GE kort i den orden til at sætte det første kort på den rigtige plads</translation>
    </message>
    <message>
        <location filename="../../src/necinput.cpp" line="982"/>
        <source>I could not create/open input.necin</source>
        <translation>Kunne ikke lava/åbne input.necin</translation>
    </message>
    <message>
        <location filename="../../src/necinputparser.cpp" line="117"/>
        <location filename="../../src/necinputparser.cpp" line="205"/>
        <source>The following line can not be parsed properly</source>
        <translation>Den følgende linje kunne ikke parses korrekt</translation>
    </message>
    <message>
        <location filename="../../src/necinputparser.cpp" line="119"/>
        <location filename="../../src/necinputparser.cpp" line="207"/>
        <source>The string list is</source>
        <translation>Strengen er</translation>
    </message>
    <message>
        <location filename="../../src/necinputparser.cpp" line="226"/>
        <location filename="../../src/necinputparser.cpp" line="234"/>
        <location filename="../../src/necinputparser.cpp" line="244"/>
        <source>QAntenna - NEC input parser</source>
        <translation>QAntenna - NEC input parser</translation>
    </message>
    <message>
        <location filename="../../src/necinputparser.cpp" line="227"/>
        <source>The file does not exists</source>
        <translation>Filen findes ikke</translation>
    </message>
    <message>
        <location filename="../../src/necinputparser.cpp" line="235"/>
        <source>I can not read the file</source>
        <translation>Kunne ikke læse filen</translation>
    </message>
    <message>
        <location filename="../../src/necinputparser.cpp" line="245"/>
        <source>The file is empty</source>
        <translation>Denne file er tom</translation>
    </message>
</context>
</TS>
